"use strict";
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jest_each_1 = __importDefault(require("jest-each"));
const fs_1 = __importDefault(require("fs"));
const util_1 = __importDefault(require("util"));
const glob_1 = __importDefault(require("glob"));
const winston_1 = require("winston");
const register_1 = __importDefault(require("./register"));
const run_1 = __importDefault(require("./run"));
const metadata = require('../package.json');
process.title = metadata.name;
const configuration = JSON.parse(process.env.SE_CONFIGURATION);
jest.setTimeout(parseInt('' + configuration.timeout));
const logger = (0, winston_1.createLogger)({
    level: configuration.debug ? 'debug' : 'info',
    transports: [
        new winston_1.transports.Console({
            format: winston_1.format.combine(winston_1.format.colorize(), winston_1.format.simple()),
        }),
    ],
});
logger.debug(util_1.default.inspect(configuration));
describe('Running all of the selected projects', () => {
    const projects = [
        ...configuration.projects.reduce((projects, project) => {
            glob_1.default.sync(project).forEach((p) => {
                projects.add(p);
            });
            return projects;
        }, new Set()),
    ].map((p) => {
        const project = JSON.parse(fs_1.default.readFileSync(p, 'utf8'));
        project.path = p;
        return project;
    });
    const factoryParams = {
        configuration,
        logger: logger,
    };
    const register = (0, register_1.default)(factoryParams);
    const runners = (0, run_1.default)(factoryParams);
    (0, jest_each_1.default)(projects).describe('Running project $name', (project) => {
        (0, jest_each_1.default)(project.suites).describe('Running suite $name', (suite) => {
            (0, jest_each_1.default)(suite.tests.map((tID) => register.test(project, tID))).it('Running tests $name', async (test) => {
                await runners.test(project, test);
            });
        });
    });
});
//# sourceMappingURL=main.test.js.map