"use strict";
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const side_runtime_1 = require("@seleniumhq/side-runtime");
const path = __importStar(require("path"));
const versioner_1 = __importDefault(require("./versioner"));
const buildRunners = ({ configuration, logger }) => {
    const runTest = async (project, test) => {
        logger.info(`Running test ${test.name}`);
        const shortenedProjectPath = project.path
            .split(path.sep)
            .slice(0, -1)
            .join(path.sep);
        const plugins = await (0, side_runtime_1.loadPlugins)(require, shortenedProjectPath, project);
        const customCommands = await (0, side_runtime_1.getCustomCommands)(plugins);
        const driver = new side_runtime_1.WebDriverExecutor({
            capabilities: configuration.capabilities,
            customCommands,
            hooks: {
                onBeforePlay: async () => {
                    await Promise.all(plugins.map((plugin) => {
                        const onBeforePlay = plugin.hooks.onBeforePlay;
                        if (onBeforePlay) {
                            return onBeforePlay({ driver });
                        }
                    }));
                },
            },
            server: configuration.server,
        });
        return await playbackUntilComplete();
        function playbackUntilComplete() {
            return new Promise((resolve, reject) => {
                const playback = new side_runtime_1.Playback({
                    baseUrl: project.url,
                    executor: driver,
                    getTestByName: (name) => project.tests.find((t) => t.name === name),
                    logger,
                    variables: new side_runtime_1.Variables(),
                });
                const onComplete = (failure) => {
                    logger.info('Completing with failure', failure);
                    playback.cleanup();
                    if (failure) {
                        return reject(failure);
                    }
                    else {
                        return resolve(null);
                    }
                };
                const EE = playback['event-emitter'];
                EE.addListener(side_runtime_1.PlaybackEvents.PLAYBACK_STATE_CHANGED, ({ state }) => {
                    logger.info(`Playing state changed ${state}`);
                    switch (state) {
                        case 'aborted':
                        case 'errored':
                        case 'failed':
                        case 'finished':
                        case 'paused':
                        case 'stopped':
                            logger.info(`Finished test ${test.name} ${state === 'finished' ? 'Success' : 'Failure'}`);
                            onComplete(state !== 'finished');
                    }
                });
                EE.addListener(side_runtime_1.PlaybackEvents.COMMAND_STATE_CHANGED, ({ id, state }) => {
                    const cmd = test.commands.find((c) => c.id === id);
                    const niceString = [cmd.command, cmd.target, cmd.value]
                        .filter((v) => !!v)
                        .join('|');
                    logger.debug(`${state} ${niceString}`);
                });
                playback.play(test, {
                    startingCommandIndex: 0,
                });
            });
        }
    };
    const runSuite = async (project, suite) => {
        logger.info(`Running suite ${suite.name}`);
        if (!project.suites.length) {
            throw new Error(`The suite ${suite.name} has no tests, add tests to the suite using the IDE.`);
        }
        for (let i = 0, ii = suite.tests.length; i != ii; i++) {
            await runTest(project, project.tests.find((t) => t.id === suite.tests[i]));
        }
        logger.info(`Finished suite ${suite.name}`);
    };
    const runProject = async (project) => {
        logger.info(`Running project ${project.name}`);
        if (!configuration.force) {
            let warning = (0, versioner_1.default)(project.version, '2.0');
            if (warning) {
                logger.warn(warning);
            }
        }
        else {
            logger.warn("--force is set, ignoring project's version");
        }
        if (!project.suites.length) {
            throw new Error(`The project ${project.name} has no test suites defined, create a suite using the IDE.`);
        }
        for (let i = 0, ii = project.suites.length; i != ii; i++) {
            await runSuite(project, project.suites[i]);
        }
        logger.info(`Finished project ${project.name}`);
    };
    const runAll = async (projects) => {
        for (let i = 0, ii = projects.length; i != ii; i++) {
            await runProject(projects[i]);
        }
    };
    return {
        all: runAll,
        project: runProject,
        suite: runSuite,
        test: runTest,
    };
};
exports.default = buildRunners;
//# sourceMappingURL=run.js.map